@@ -6,16 +6,20 @@ lib = File.expand_path('../lib', __FILE__)
 $LOAD_PATH.unshift(lib) unless $LOAD_PATH.include?(lib)
 require 'jekyll-sass-converter'
 
-Jekyll.logger.log_level = Jekyll::Stevenson::ERROR
+if Jekyll::VERSION > "1"
+  Jekyll.logger.log_level = :error
+else
+  Jekyll.logger.log_level = Jekyll::Stevenson::ERROR
+end
 
 RSpec.configure do |config|
-  config.treat_symbols_as_metadata_keys_with_true_values = true
   config.run_all_when_everything_filtered = true
   config.filter_run :focus
   config.order = 'random'
 
-  SOURCE_DIR = File.expand_path("../source", __FILE__)
-  DEST_DIR   = File.expand_path("../dest",   __FILE__)
+  SOURCE_DIR   = File.expand_path("../source", __FILE__)
+  DEST_DIR     = File.expand_path("../dest",   __FILE__)
+  SASS_LIB_DIR = File.expand_path("../other_sass_library", __FILE__)
   FileUtils.rm_rf(DEST_DIR)
   FileUtils.mkdir_p(DEST_DIR)
 
@@ -27,6 +31,10 @@ RSpec.configure do |config|
     File.join(DEST_DIR, *files)
   end
 
+  def sass_lib(*files)
+    File.join(SASS_LIB_DIR, *files)
+  end
+
   def site_configuration(overrides = {})
     Jekyll.configuration(overrides.merge({
       "source"      => source_dir,
